function introduction;

execute_section(1);
% Create the signal flow graph
sfg = [];
sfg = addoperand(sfg, 'in', 1, 1);
sfg = addoperand(sfg, 'add', 1, [1 2], 3);
sfg = addoperand(sfg, 'delay', 1, 3, 4);
sfg = addoperand(sfg, 'mult', 1, 4, 2, 0.5);
sfg = addoperand(sfg, 'out', 1, 4);

printsfg(sfg); % Print the signal flow graph
% end section 1


execute_section(2);
% Print complexity
printcomplexity(sfg);
% end section 2


execute_section(4);
% Simulate
n = 200; % Number of input samples
x = linspace(0, 2*pi, n);
input = sin(x) + 2*sin(256*x);
output = simulate(sfg, input);
figure;
subplot(2, 1, 1);
plot(0:n - 1, input);
title('Input');
subplot(2, 1, 2);
plot(0:n - 1, output);
title('Output');
% end section 4


execute_section(5);
% Impulse and stepresponse
n_imp = 30; % Number of samples in impulse and step response
h = impulseresponse(sfg, n_imp, 1);
stepresponse(sfg, n_imp, 1);
figure;
freqz(h);
% end section 5


execute_section(6);
% Insert pipeline register
sfg = insertoperand(sfg, 'delay', 2, 1);

% Precedence form of the signal flow graph
printprecedence(sfg);
plotprecedence(sfg);
impulseresponse(sfg, n_imp, 1);
% end section 6


execute_section(7);
% Change the coefficient value
sfg = changeoperand(sfg, 'mult', 1, -0.1);
stepresponse(sfg, n_imp, 1);
h = impulseresponse(sfg, n_imp);
figure;
freqz(h);
% end section 7
